==> haskell-microaeson-0.1.0.1-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microaeson
version:              0.1.0.1
visibility:           public
id:                   microaeson-0.1.0.1-4GPYwP3ywsgBaSPfc1ag5D
key:                  microaeson-0.1.0.1-4GPYwP3ywsgBaSPfc1ag5D
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  1f630eea1805ba64e99107969bf078f0
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.2.8/site-local/microaeson-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/microaeson-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.1-4GPYwP3ywsgBaSPfc1ag5D
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microaeson-0.1.0.2-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microaeson
version:              0.1.0.2
visibility:           public
id:                   microaeson-0.1.0.2-IttaQh6B0VjDojlSU3Mhlg
key:                  microaeson-0.1.0.2-IttaQh6B0VjDojlSU3Mhlg
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  7b824fb5fdd091629086ffb1bea31214
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.2.8/site-local/microaeson-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/microaeson-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.2-IttaQh6B0VjDojlSU3Mhlg
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
